#!/bin/sh
export PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin:/usr/local/zy-pkgs/bin
. /etc/profile
bsname=${0##/*/}

if [ ! -e /i-data/.zyxel/zy-pkgs/config/Syslog/enable_syslog.flag ]; then
	echo "${bsname}: enable_syslog.flag not exist"
	exit 0
fi

if [ ! -e /i-data/.zyxel/zy-pkgs/config/Syslog/syslog.table ]; then
	syslog_dir="/i-data/md0/admin/"
else
	syslog_dir=`cat /i-data/.zyxel/zy-pkgs/config/Syslog/syslog.table|cut -d '|' -f 1`
fi

if [ ! -e $syslog_dir ] || [ "${syslog_dir}" == "" ]; then
	echo "${bsname}: skip, $syslog_dir not exist"
	exit 0
fi

if [ -e /tmp/syslog_filmgmt.lock ]; then
	echo "${bsname}: skip, /tmp/syslogng.lock exist"
	exit 0
fi

if [ -e /i-data/.zyxel/ ]; then
	logfile="/i-data/.zyxel/storage.txt"
else
	logfile="/tmp/michael.txt"
fi

# 500 MB freespace check
if [ "$1" != "" ]; then
	ACTIVE=`cat /proc/d_suspdtime|grep " ACTIVE"`
	if [ "${ACTIVE}" != "" ]; then
		freeKB=`df ${syslog_dir}|awk '{print $4}'|tail -n 1`
		if [ $freeKB -le $1 ]; then
			echo "zylogger -s 28 -p 0 -f 28 Syslog Log Destination Volume FreeSpace is smaller than ${freeKB} KB" >> ${logfile}
			echo "zylogger -s 28 -p 0 -f 28 Syslog Log Destination Volume FreeSpace is smaller than ${freeKB} KB" > /dev/console
			zylogger -s 28 -p 0 -f 28 "Syslog Log Destination Volume FreeSpace is smaller than ${freeKB} KB"
		fi
	fi
	exit 0
fi

touch /tmp/syslog_filmgmt.lock

YYYY=`date +%Y`
let "lastYYYY = $YYYY - 1"
MM=`date +%m`
all_dir=`ls $syslog_dir|grep -E "^(${YYYY}|${lastYYYY})[0-9][0-9]$"|grep -v "${YYYY}${MM}"`
echo "${bsname}:handle ${all_dir}" >> ${logfile}
for dir in ${all_dir}; do
	if [ -e ${syslog_dir}${dir}.tgz ]; then
		echo "skip ${syslog_dir}${dir}.tgz:tar exists" >> ${logfile}
		echo "skip ${syslog_dir}${dir}.tgz:tar exists" > /dev/consle
		continue
	fi
	echo "tar zcvf ${syslog_dir}${dir}.tgz -C ${syslog_dir} ${dir} >/dev/console 2>&1" >> ${logfile}
	echo "tar zcvf ${syslog_dir}${dir}.tgz -C ${syslog_dir} ${dir} >/dev/console 2>&1" > /dev/consle
	tar zcvf ${syslog_dir}${dir}.tgz -C ${syslog_dir} ${dir} >/dev/console 2>&1
	del=$?
	chmod 777 ${syslog_dir}${dir}.tgz
	if [ $del -eq 0 ]; then
		#172.23.26.247_20090520.txt
		#find ${syslog_dir}${dir} -name "*.*.*.*_*.txt" -exec echo "rm -f '{}'"\; rm -f '{}'\; \; > ${logfile} 2>&1
		find ${syslog_dir}${dir} -name "*.*.*.*_*.txt" >> ${logfile}
		rm -f `find ${syslog_dir}${dir} -name "*.*.*.*_*.txt"`
		rmdir ${syslog_dir}${dir}
	else
		echo "return $del:tar failed" >> ${logfile}
		echo "return $del:tar failed" > /dev/consle
		rm -f /tmp/syslog_filmgmt.lock
		exit 1
	fi
done

# auto purge
autopurge=`cat /i-data/.zyxel/zy-pkgs/config/Syslog/syslog.table|cut -d '|' -f 3`
if [ "${autopurge}" == "" ]; then
	autopurge=6
fi
if [ "${autopurge}" != "0" ]; then
	all_tgz=`ls $syslog_dir|grep -E "^(${YYYY}|${lastYYYY})[0-9][0-9].tgz$"|grep -v "${YYYY}${MM}"`
	echo "${bsname}:handle ${all_tgz}" >> ${logfile}
	valueMM=`echo $MM|awk '{print $1-0}'`
	for tgz in ${all_tgz}; do
		# auto purge
		YYYY_tgz=`echo ${tgz}|cut -c 1-4`
		MM1_tgz=`echo ${tgz}|cut -c 5-6`
		echo ${YYYY_tgz}${MM1_tgz} > /dev/console
		MM_tgz=`echo $MM1_tgz|awk '{print $1-0}'`
		let "ageYYYY = $YYYY - $YYYY_tgz"
		let "ageMM = $valueMM - $MM_tgz"
		echo ageYYYY=${ageYYYY},ageMM=${ageMM} > /dev/console
		let "age = ${ageYYYY}*12 + $ageMM"

		if [ $age -gt $autopurge ]; then
			echo "${bsname}:rm -f ${syslog_dir}${tgz}" >> ${logfile}
			rm -f ${syslog_dir}${tgz}
		fi
	done
fi
rm -f /tmp/syslog_filmgmt.lock
