#!/bin/sh
# This script will be called by "syslogng_gen_conf.sh" and "SIGHUP event handler in syslog-ng" (src/main.c)
# What this script did: read ${ARGS_FILE} and use it's contents as arguments to generate "syslog-ng-pkg.conf"

export PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin:/usr/local/zy-pkgs/bin
. /etc/profile
bsname=${0##/*/}


ARGS_FILE="/tmp/syslog_args"	# format: $1|$2
FW_SYSLOGNG_CONF="/etc/syslog-ng/syslog-ng.conf"
PKG_SYSLOGNG_CONF="/etc/syslog-ng/syslog-ng-pkg.conf"
PKG_SYSLOGNG_CONF_TMP="/tmp/syslog-ng-pkg.conf"

HEADER='# generated by '${0}
HEADER_FROM_FW='# copied from '${FW_SYSLOGNG_CONF}
HEADER_FROM_PKG='# copied from '${FW_SYSLOGNG_CONF}

S_NET='source s_net {
	udp(ip(0.0.0.0) port(514));
	tcp(ip(0.0.0.0) port(514));
	udp(ip(0.0.0.0) port(601));
	tcp(ip(0.0.0.0) port(601));
};'


rm /tmp/syslog_fail.log
if [ ! -f ${ARGS_FILE} ]; then
	if [ ! -f ${PKG_SYSLOGNG_CONF} ]; then	# sighup case: ${PKG_SYSLOGNG_CONF} must exist!
		echo "cannot find ${ARGS_FILE} or ${PKG_SYSLOGNG_CONF}"	| tee /tmp/syslog_fail.log
		exit 1
	fi

	T_NET="`cat ${PKG_SYSLOGNG_CONF} | grep -A3 \"template t_net {\"`"
	D_NET="`cat ${PKG_SYSLOGNG_CONF} | grep -A3 \"destination d_net {\"`"
else
	TEMPLATE_ARG="`cat ${ARGS_FILE} | awk -F'|' '{print $1}'`"
	DESTINATION_ARG="`cat ${ARGS_FILE} | awk -F'|' '{print $2}'`"
	
	#$1='"$DATE\t$HOST\t$MESSAGE\n"'
	T_NET='
template t_net {
	template('${TEMPLATE_ARG}');
	template_escape(no);
};
'

	#$2='"/i-data/md0/admin/${YEAR}${MONTH}/${SOURCEIP}__${YEAR}${MONTH}${DAY}.txt"'
	D_NET='
destination d_net {
#	file("/i-data/md0/admin/${YEAR}${MONTH}/${SOURCEIP}_${YEAR}${MONTH}${DAY}.txt" template(t_net)owner(admin) perm(0777));
	file('${DESTINATION_ARG}' template(t_net) owner(admin) group(everyone) perm(0777) dir_owner(admin) dir_group(everyone) dir_perm(0777) create_dirs(yes));
};
'	
	mv ${ARGS_FILE} ${ARGS_FILE}.bak
fi

LOG_NET='log { source(s_net); destination(d_net); };'


if [ -e /tmp/syslogng.lock ]; then
	echo "${bsname}: sleep 3: /tmp/syslogng.lock exist" > /dev/console
	sleep 3
	if [ -e /tmp/syslogng.lock ]; then
		echo "${bsname}: skip, /tmp/syslogng.lock exist" > /dev/console
		exit 0
	fi
fi

touch /tmp/syslogng.lock


# generate ${PKG_SYSLOGNG_CONF_TMP}
echo "${HEADER}"				> "${PKG_SYSLOGNG_CONF_TMP}"
echo							>> "${PKG_SYSLOGNG_CONF_TMP}"
echo "${HEADER_FROM_FW}"		>> "${PKG_SYSLOGNG_CONF_TMP}"

# 1. dump all contents from ${FW_SYSLOGNG_CONF}
# 2. remove "tcp(ip("127.0.0.1")); " in s_sys block
# 3. replace all "s_sys" with "s_local"
cat ${FW_SYSLOGNG_CONF} |				\
	sed -e 's/tcp(ip(\"127.0.0.1\")); //' |		\
	sed -e 's/s_sys\([^0-9A-Za-z]\)/s_local\1/g'		\
					>> "${PKG_SYSLOGNG_CONF_TMP}"

# add s_net, t_net, d_net, and log (s_net, d_net)
echo						>> "${PKG_SYSLOGNG_CONF_TMP}"
echo "${HEADER_FROM_PKG}"			>> "${PKG_SYSLOGNG_CONF_TMP}"
echo "${S_NET}"					>> "${PKG_SYSLOGNG_CONF_TMP}"
echo "${T_NET}"					>> "${PKG_SYSLOGNG_CONF_TMP}"
echo "${D_NET}"					>> "${PKG_SYSLOGNG_CONF_TMP}"
echo "${LOG_NET}"				>> "${PKG_SYSLOGNG_CONF_TMP}"


cp "${PKG_SYSLOGNG_CONF_TMP}" "${PKG_SYSLOGNG_CONF}"
chmod 777 "${PKG_SYSLOGNG_CONF}"

rm -f /tmp/syslogng.lock

